@@ -24,8 +24,8 @@
  */
 
 module jdk.internal.vm.compiler {
-    // source file: file:///scratch/opt/mach5/mesos/work_dir/slaves/2dd962d0-8988-479b-a804-57ab764ada59-S1197/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/c390ded4-303f-4aa3-a72e-e7857177a3dd/runs/06a57563-23c8-4057-a6ac-a34cd2be93a6/workspace/open/src/jdk.internal.vm.compiler/share/classes/module-info.java
-    //              file:///scratch/opt/mach5/mesos/work_dir/slaves/2dd962d0-8988-479b-a804-57ab764ada59-S1197/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/c390ded4-303f-4aa3-a72e-e7857177a3dd/runs/06a57563-23c8-4057-a6ac-a34cd2be93a6/workspace/build/linux-x64-open/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
+    // source file: file:///scratch/opt/mach5/mesos/work_dir/slaves/dd0bab7c-a530-4905-bb6b-daa7153eb2c1-S60/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/7b9bbb18-6977-45a8-a8b3-112df32bb32b/runs/25f688c6-97bf-45a5-8e15-c185b0836da4/workspace/open/src/jdk.internal.vm.compiler/share/classes/module-info.java
+    //              file:///scratch/opt/mach5/mesos/work_dir/slaves/dd0bab7c-a530-4905-bb6b-daa7153eb2c1-S60/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/7b9bbb18-6977-45a8-a8b3-112df32bb32b/runs/25f688c6-97bf-45a5-8e15-c185b0836da4/workspace/build/linux-x64-open/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
     requires java.instrument;
     requires java.management;
     requires jdk.internal.vm.ci;
@@ -65,6 +65,7 @@ module jdk.internal.vm.compiler {
         jdk.aot,
         jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.phases to jdk.aot;
+    exports org.graalvm.compiler.phases.common.jmx to jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.phases.tiers to jdk.aot;
     exports org.graalvm.compiler.printer to jdk.aot;
     exports org.graalvm.compiler.replacements to jdk.aot;
@@ -84,12 +85,14 @@ module jdk.internal.vm.compiler {
     uses org.graalvm.compiler.hotspot.HotSpotGraalManagementRegistration;
     uses org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory;
     uses org.graalvm.compiler.options.OptionDescriptors;
-    uses org.graalvm.compiler.serviceprovider.GraalServices.JMXService;
+    uses org.graalvm.compiler.phases.common.jmx.HotSpotMBeanOperationProvider;
+    uses org.graalvm.compiler.serviceprovider.JMXService;
     provides jdk.vm.ci.services.JVMCIServiceLocator with org.graalvm.compiler.hotspot.HotSpotGraalJVMCIServiceLocator;
     provides org.graalvm.compiler.code.DisassemblerProvider with
         org.graalvm.compiler.code.HexCodeFileDisassemblerProvider,
         org.graalvm.compiler.hotspot.meta.HotSpotDisassemblerProvider;
     provides org.graalvm.compiler.core.match.MatchStatementSet with
+        org.graalvm.compiler.core.aarch64.AArch64NodeMatchRules_MatchStatementSet,
         org.graalvm.compiler.core.amd64.AMD64NodeMatchRules_MatchStatementSet,
         org.graalvm.compiler.core.sparc.SPARCNodeMatchRules_MatchStatementSet;
     provides org.graalvm.compiler.debug.DebugHandlersFactory with org.graalvm.compiler.printer.GraalDebugHandlersFactory;
@@ -106,14 +109,12 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AcquiredCASLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AllocaNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_BeginLockScopeNode,
-        org.graalvm.compiler.hotspot.nodes.PluginFactory_ComputeObjectAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentJavaThreadNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DimensionsNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_EndLockScopeNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_FastAcquireBiasedLockNode,
-        org.graalvm.compiler.hotspot.nodes.PluginFactory_GetObjectAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_GraalHotSpotVMConfigNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_JumpToExceptionHandlerInCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_JumpToExceptionHandlerNode,
@@ -140,24 +141,20 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_MonitorSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_StringToBytesSnippets,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA2Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ThreadSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_WriteBarrierSnippets,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopyCallNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopySnippets,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopyWithSlowPathNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProbabilisticProfileSnippets,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProfileSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_CreateExceptionStub,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_ExceptionHandlerStub,
-        org.graalvm.compiler.hotspot.stubs.PluginFactory_NewArrayStub,
-        org.graalvm.compiler.hotspot.stubs.PluginFactory_NewInstanceStub,
+        org.graalvm.compiler.hotspot.stubs.PluginFactory_ForeignCallSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_StubUtil,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_UnwindExceptionToCallerStub,
         org.graalvm.compiler.nodes.PluginFactory_BreakpointNode,
+        org.graalvm.compiler.nodes.PluginFactory_ComputeObjectAddressNode,
         org.graalvm.compiler.nodes.PluginFactory_DeoptimizeNode,
+        org.graalvm.compiler.nodes.PluginFactory_GetObjectAddressNode,
         org.graalvm.compiler.nodes.PluginFactory_PauseNode,
         org.graalvm.compiler.nodes.PluginFactory_PiArrayNode,
         org.graalvm.compiler.nodes.PluginFactory_PiNode,
@@ -174,20 +171,33 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.extended.PluginFactory_UnsafeCopyNode,
         org.graalvm.compiler.nodes.java.PluginFactory_ArrayLengthNode,
         org.graalvm.compiler.nodes.java.PluginFactory_DynamicNewArrayNode,
+        org.graalvm.compiler.nodes.java.PluginFactory_InstanceOfNode,
         org.graalvm.compiler.nodes.java.PluginFactory_NewArrayNode,
         org.graalvm.compiler.nodes.java.PluginFactory_RegisterFinalizerNode,
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
         org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
         org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
         org.graalvm.compiler.replacements.PluginFactory_Log,
+        org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
         org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64FloatArithmeticSnippets,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64IntegerArithmeticSnippets,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOf,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOfNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64MathSubstitutions,
-        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringIndexOfNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1InflateNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1Substitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringSubstitutions,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16CompressNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16Substitutions,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyCallNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopySnippets,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyWithSlowPathNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayCompareToNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayEqualsNode,
+        org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayRegionEqualsNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_AssertionNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BinaryMathIntrinsicNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BitScanForwardNode,
@@ -198,8 +208,8 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode;
     provides org.graalvm.compiler.options.OptionDescriptors with
         org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
-        org.graalvm.compiler.core.amd64.AMD64NodeLIRBuilder_OptionDescriptors,
         org.graalvm.compiler.core.common.GraalOptions_OptionDescriptors,
+        org.graalvm.compiler.core.common.SpeculativeExecutionAttacksMitigations_OptionDescriptors,
         org.graalvm.compiler.core.common.spi.JavaConstantFieldProvider_OptionDescriptors,
         org.graalvm.compiler.core.common.util.CompilationAlarm_OptionDescriptors,
         org.graalvm.compiler.core.phases.HighTier_OptionDescriptors,
@@ -213,6 +223,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.CompilationWatchDog_OptionDescriptors,
         org.graalvm.compiler.hotspot.CompilerConfigurationFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotBackend_OptionDescriptors,
+        org.graalvm.compiler.hotspot.HotSpotCompiledCodeBuilder_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotGraalCompilerFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider_OptionDescriptors,
         org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
@@ -229,10 +240,6 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.lir.alloc.lsra.LinearScanEliminateSpillMovePhase_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScan_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.OptimizingLinearScanWalker_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.DefaultTraceRegisterAllocationPolicy_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.TraceBuilderPhase_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.TraceRegisterAllocationPhase_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.lsra.TraceLinearScanPhase_OptionDescriptors,
         org.graalvm.compiler.lir.amd64.phases.StackMoveOptimizationPhase_OptionDescriptors,
         org.graalvm.compiler.lir.asm.CompilationResultBuilder_OptionDescriptors,
         org.graalvm.compiler.lir.constopt.ConstantLoadOptimization_OptionDescriptors,
