@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -134,6 +134,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Australian Central Time (Northern Territory)",
                "ACT",
             };
+        final String[] JRE_Asia_Qostanay = new String[] {
+               "Qostanay Time",
+               "GMT+06:00",
+               "Qostanay Summer Time",
+               "GMT+06:00",
+               "Qostanay Time",
+               "GMT+06:00",
+            };
         final String[] Lord_Howe = new String[] {
                "Lord Howe Standard Time",
                "LHST",
@@ -2063,6 +2071,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "Africa/Djibouti", Africa_Eastern },
             { "EST", America_Eastern },
+            { "Asia/Qostanay", JRE_Asia_Qostanay },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
